Build and install the Testing Runtime APEX in ART device testing.
Replace the Debug Runtime APEX with the Testing Runtime APEX for ART
device testing.
This change does not change the behavior of ART device testing per se,
as test rules have not been updated (yet) to make use of the
additional files (ART gtests) included only in the Testing Runtime
APEX.
Test: ART (chroot-based) device testing
Bug: 129534335
Change-Id: I1b9dfcb9fe483584b4065908c1b2e24d19703b52
diff --git a/tools/buildbot-sync.sh b/tools/buildbot-sync.sh
index 65be158..6fac2d0 100755
--- a/tools/buildbot-sync.sh
+++ b/tools/buildbot-sync.sh
@@ -140,10 +140,10 @@
"$ART_TEST_CHROOT/system/etc/public.libraries.txt"
echo -e "${green}Activating Runtime APEX...${nc}"
# Manually "activate" the flattened Debug Runtime APEX by syncing it to the
# /apex directory in the chroot.
#
# We copy the files from `/system/apex/com.android.runtime.debug` to
# `/apex/com.android.runtime` in the chroot directory, instead of simply using a
# symlink, as Bionic's linker relies on the real path name of a binary
# (e.g. `/apex/com.android.runtime/bin/dex2oat`) to select the linker
@@ -153,7 +153,7 @@
# As a workaround, one can run `export TARGET_FLATTEN_APEX=true` before building
# a target to have its APEX packages flattened.
adb shell rm -rf "$ART_TEST_CHROOT/apex/com.android.runtime"
-adb shell cp -a "$ART_TEST_CHROOT/system/apex/com.android.runtime.debug" \
+adb shell cp -a "$ART_TEST_CHROOT/system/apex/com.android.runtime.testing" \
"$ART_TEST_CHROOT/apex/com.android.runtime"
echo -e "${green}Activating Time Zone Data APEX...${nc}"
@@ -140,10 +140,10 @@
"$ART_TEST_CHROOT/system/etc/public.libraries.txt"
echo -e "${green}Activating Runtime APEX...${nc}"
-# Manually "activate" the flattened Debug Runtime APEX by syncing it to the
+# Manually "activate" the flattened Testing Runtime APEX by syncing it to the
# /apex directory in the chroot.
#
@@ -140,10 +140,10 @@
# /apex directory in the chroot.
#
-# We copy the files from `/system/apex/com.android.runtime.debug` to
+# We copy the files from `/system/apex/com.android.runtime.testing` to
# `/apex/com.android.runtime` in the chroot directory, instead of simply using a
# symlink, as Bionic's linker relies on the real path name of a binary